/**
 * @module direction/utils
 */

/**
 * The list of supported direction options:
 *
 * * `'ltr'`,
 * * `'rtl'`,
 */
export const supportedOptions = [ 'ltr', 'rtl' ];

/**
 * Checks whether the passed option is supported by {@link module:direction/directionediting~DirectionEditing}.
 *
 * @param {String} option The option value to check.
 * @returns {Boolean}
 */
export function isSupported( option ) {
  return supportedOptions.includes( option );
}

/**
 * Compare a direction string with current document (<html>) direction.
 *
 * @param {String} direction , expected 'ltr' or 'rtl'.
 * @returns {Boolean}
 */
export function isDefault(direction) {
  // Get the computed direction of the root HTML element or default it to ltr.
  // We do not rely on <html>  dir attribute since in rare cases it may not exist.
  const rootHtmlDirection = window.getComputedStyle(document.documentElement).direction || 'ltr';
  return direction === rootHtmlDirection;
}
